@@ -129,8 +129,8 @@ class Wsdl(WsdlBase):
             'groups': [
                 lambda group: group(_("Repository"),
                                     brief=('cl_update_profile_repo_name',),
-                                    # hide=('cl_update_profile_url',
-                                    #       'cl_update_profile_sync_set'),
+                                    hide=('cl_update_profile_url',
+                                          'cl_update_profile_sync_set'),
                                     normal=('cl_update_profile_url',),
                                     expert=('cl_update_profile_sync_set',)),
                 lambda group: group(_("Profile"),
